==> joker-flasky-0.0.1.tar.gz: joker-flasky-0.0.1/joker/flasky/serialize.py <==
#!/usr/bin/env python3
# coding: utf-8

from __future__ import unicode_literals

import codecs
import datetime
import decimal
import json


def jsonencoder_default(encoder, obj):
    if hasattr(obj, 'as_json_serializable'):
        return obj.as_json_serializable()
    datetime_types = datetime.datetime, datetime.date, datetime.time
    if isinstance(obj, datetime_types):
        return obj.isoformat()
    elif isinstance(obj, datetime.timedelta):
        return obj.total_seconds()

    elif isinstance(obj, decimal.Decimal):
        return float(obj)
    else:
        return encoder.default(vars(obj))


class JSONEncoderExt(json.JSONEncoder):
    default = jsonencoder_default


def indented_json_dumps(obj, **kwargs):
    kwargs.setdefault('indent', 4)
    kwargs.setdefault('ensure_ascii', False)
    kwargs.setdefault('cls', JSONEncoderExt)
    return json.dumps(obj, **kwargs)


def indented_json_print(obj, **kwargs):
    print_kwargs = {}
    for k in ['sep', 'end', 'file', 'flush']:
        if k in kwargs:
            print_kwargs[k] = kwargs.pop(k)
    s = indented_json_dumps(obj, **kwargs)
    print(s, **print_kwargs)


# might be useless
def indented_json_print_legacy(obj, **kwargs):
    # https://stackoverflow.com/a/12888081/2925169
    decoder = codecs.getdecoder('unicode_escape')
    print_kwargs = {}
    for k in ['sep', 'end', 'file', 'flush']:
        if k in kwargs:
            print_kwargs[k] = kwargs.pop(k)
    kwargs.setdefault('indent', 4)
    s = json.dumps(obj, **kwargs)
    print(decoder(s)[0], **print_kwargs)

==> joker-flasky-0.0.3.tar.gz: joker-flasky-0.0.3/joker/flasky/serialize.py <==
#!/usr/bin/env python3
# coding: utf-8

from __future__ import unicode_literals

import codecs
import datetime
import json
import uuid
import decimal


def jsonp(resp, callback):
    import flask
    return flask.current_app.response_class(
        callback + '(' + flask.json.dumps(resp) + ');\n',
        mimetype='application/javascript'
    )


class JSONEncoderExt(json.JSONEncoder):
    def default(self, o):
        if hasattr(o, 'as_json_serializable'):
            return o.as_json_serializable()
        if isinstance(o, decimal.Decimal):
            return float(o)
        if isinstance(o, datetime.timedelta):
            return o.total_seconds()
        if isinstance(o, (datetime.datetime, datetime.date)):
            return o.isoformat()
        if isinstance(o, uuid.UUID):
            return str(o)
        return super(JSONEncoderExt, self).default(o)


def indented_json_dumps(obj, **kwargs):
    kwargs.setdefault('indent', 4)
    kwargs.setdefault('ensure_ascii', False)
    kwargs.setdefault('cls', JSONEncoderExt)
    return json.dumps(obj, **kwargs)


def indented_json_print(obj, **kwargs):
    print_kwargs = {}
    for k in ['sep', 'end', 'file', 'flush']:
        if k in kwargs:
            print_kwargs[k] = kwargs.pop(k)
    s = indented_json_dumps(obj, **kwargs)
    print(s, **print_kwargs)


# might be useless
def indented_json_print_legacy(obj, **kwargs):
    # https://stackoverflow.com/a/12888081/2925169
    decoder = codecs.getdecoder('unicode_escape')
    print_kwargs = {}
    for k in ['sep', 'end', 'file', 'flush']:
        if k in kwargs:
            print_kwargs[k] = kwargs.pop(k)
    kwargs.setdefault('indent', 4)
    s = json.dumps(obj, **kwargs)
    print(decoder(s)[0], **print_kwargs)
